# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name hashtables

Name:           ghc-%{pkg_name}
Version:        1.0.1.8
Release:        4%{?dist}
Summary:        Mutable hash tables in the ST monad

License:        BSD
URL:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-vector-devel
# End cabal-rpm deps

%description
This package provides a couple of different implementations of mutable
hash tables in the ST monad, as well as a typeclass abstracting their
common operations, and a set of wrappers to use the hash tables in the
IO monad.

This package currently contains three hash table implementations:

1. Data.HashTable.ST.Basic contains a basic open-addressing hash table
using linear probing as the collision strategy.

2. Data.HashTable.ST.Cuckoo contains an implementation of "cuckoo hashing"
which has worst-case O(1) lookups and can reach a high "load factor".

3. Data.HashTable.ST.Linear contains a linear hash table, which trades
some insert and lookup performance for higher space efficiency and
much shorter delays when expanding the table.


%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post devel
%ghc_pkg_recache


%postun devel
%ghc_pkg_recache


%files -f %{name}.files
%doc LICENSE


%files devel -f %{name}-devel.files
%doc README.md


%changelog
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 07 2013 Jens Petersen <petersen@redhat.com> - 1.0.1.8-3
- update to new simplified Haskell Packaging Guidelines

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Oct 29 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.8-1
- update to 1.0.1.8

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.6-2
- change prof BRs to devel

* Wed Jun 13 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.6-1
- update to 1.0.1.6

* Sun May  6 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.3-2
- build needs ghci

* Thu Mar 22 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.3-1
- update to 1.0.1.3

* Thu Mar  8 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.2-2
- rebuild

* Mon Jan 16 2012 Jens Petersen <petersen@redhat.com> - 1.0.1.2-1
- BSD
- depends on hashable and vector

* Mon Jan 16 2012 Fedora Haskell SIG <haskell-devel@lists.fedoraproject.org>
- spec file template generated by cabal2spec-0.25.2
